#include "rational.hpp"
#include <sstream>

Rational::Rational(int z, int n) : zaehler(z), nenner(n) {
	if(nenner < 0){
		nenner = -nenner;
		zaehler = -zaehler;
	}
}

std::string Rational::toString() const {
	std::stringstream strstr;
	strstr << zaehler << "/" << nenner;
	return strstr.str();
}

Rational Rational::operator*(const Rational& rechts) const {
	Rational ergebnis(this->zaehler * rechts.zaehler, this->nenner * rechts.nenner);
	return ergebnis;
}

Rational& Rational::operator*=(const Rational& rechts) {
	this->zaehler *= rechts.zaehler;
	this->nenner *= rechts.nenner;
	return *this;
}

Rational Rational::operator+(const Rational& rechts) const {
	Rational ergebnis(this->zaehler*rechts.nenner + rechts.zaehler*this->nenner, this->nenner*rechts.nenner);
	return ergebnis;
}

Rational& Rational::operator+=(const Rational& rechts) {
	this->zaehler = this->zaehler*rechts.nenner + rechts.zaehler*this->nenner;
	this->nenner *= rechts.nenner;
	return *this;
}

Rational Rational::operator-(const Rational& rechts) const {
	Rational ergebnis(this->zaehler*rechts.nenner - rechts.zaehler*this->nenner, this->nenner*rechts.nenner);
	return ergebnis;
}

Rational& Rational::operator-=(const Rational& rechts) {
	this->zaehler = this->zaehler*rechts.nenner - rechts.zaehler*this->nenner;
	this->nenner *= rechts.nenner;
	return *this;
}

Rational Rational::operator/(const Rational& rechts) const {
	Rational ergebnis(this->zaehler / rechts.zaehler, this->nenner / rechts.nenner);
	return ergebnis;
}

Rational& Rational::operator/=(const Rational& rechts) {
	this->zaehler /= rechts.zaehler;
	this->nenner /= rechts.nenner;
	return *this;
}

bool Rational::operator==(const Rational& rechts) {
	return this->zaehler*rechts.nenner == rechts.zaehler*this->nenner;
}

bool Rational::operator!=(const Rational& rechts) {
	return this->zaehler*rechts.nenner != rechts.zaehler*this->nenner;
}

bool Rational::operator<(const Rational& rechts) {
	return this->zaehler*rechts.nenner < rechts.zaehler*this->nenner;
}

bool Rational::operator<=(const Rational& rechts) {
	return this->zaehler*rechts.nenner <= rechts.zaehler*this->nenner;
}

bool Rational::operator>(const Rational& rechts) {
	return this->zaehler*rechts.nenner > rechts.zaehler*this->nenner;
}

bool Rational::operator>=(const Rational& rechts) {
	return this->zaehler*rechts.nenner >= rechts.zaehler*this->nenner;
}

std::ostream& operator<<(std::ostream& os, const Rational& r){
	os << r.toString();
	return os;
}

